@@ -10,7 +10,7 @@ namespace Evolution {
 			return ((int)time.Subtract (local_epoch).TotalSeconds);
 		}
 	
-		[DllImport("glib-2.0")]
+		[DllImport("libglib-2.0.so.0")]
 		public static extern int g_slist_length (IntPtr slist);
 		
                 [DllImport("glibsharpglue")]
@@ -19,7 +19,7 @@ namespace Evolution {
 		[DllImport("glibsharpglue")]
 		public static extern  IntPtr gtksharp_slist_get_next (IntPtr slist);
  
-		[DllImport("glib-2.0")]
+		[DllImport("libglib-2.0.so.0")]
 		public static extern void g_slist_free (IntPtr slist);
 
 		public static string[] GLibSListToStringArray (IntPtr slist, bool free_list_mem)
